# BigEarthNet-S1 v1.0 Tools
This repository contains tools for processing the BigEarthNet Sentinel-1 (denoted as BigEarthNet-S1) v1.0 benchmark archive.
For the detailed explanation about the archive and downloading the archive, you can visit the website of BigEarthNet, [http://bigearth.net/](http://bigearth.net/).

* Tools are written in Python at the moment.
* All the codes are tested in Python 2.7 and 3.5 on Ubuntu 16.04 at the moment.
* To use the tools, you may need to first download the archive and/or the lists of image patches with seasonal snow and cloud&shadow from the website. 

If you use the BigEarthNet-S1 v1.0 tools, please cite the paper given below:

> G. Sumbul, A. d. Wall, T. Kreuziger, F. Marcelino, H. Costa, P. Benevides, M. Caetano, B. Demir, V. Markl, “[BigEarthNet-MM: A Large Scale Multi-Modal Multi-Label Benchmark Archive for Remote Sensing Image Classification and Retrieval](https://arxiv.org/abs/2105.07921)”,  IEEE Geoscience and Remote Sensing Magazine, vol. 9, no. 3, pp. 174-180, 2021, doi: 10.1109/MGRS.2021.3089174.

```
@article{BigEarthNet-MM,
      title={BigEarthNet-MM: A Large Scale Multi-Modal Multi-Label Benchmark Archive for Remote Sensing Image Classification and Retrieval}, 
      author={Gencer Sumbul, Arne de Wall, Tristan Kreuziger, Filipe Marcelino, Hugo Costa, Pedro Benevides, Mário Caetano, Begüm Demir and Volker Markl},
      journal={IEEE Geoscience and Remote Sensing Magazine},
      volume={9},
      number={3},
      pages={174-180},
      year={2021},
      doi={10.1109/MGRS.2021.3089174}
}
```

List of Tools and How to Use Them
-----
 
#### Python script to read Sentinel-1 image patches in the BigEarthNet-S1 v1.0 archive ([read_patch.py](https://git.tu-berlin.de/rsim/BigEarthNet-S1_tools/-/blob/master/scripts/read_patch.py))

This example script reads GeoTIFF files for each radar band of a Sentinel-1 image patch in the BigEarthNet-S1 v1.0 archive.
The script is capable of reading either all spectral bands of one patch folder (-p option) or all bands for all patches (-r option).
After reading files, Sentinel-1 image values can be used as numpy array for further purposes. 

* Examples:

```
python read_patch.py -p BigEarthNet-S1-v1.0/S2A_MSIL2A_20171104T095201_5_43/
python read_patch.py -r BigEarthNet-S1-v1.0/
```

* Requirements for running:

The BigEarthNet-S1 v1.0 archive should be downloaded first. Either [GDAL](https://pypi.org/project/GDAL/) or [rasterio](https://github.com/mapbox/rasterio/) package should be installed. To use the resulting pixel values, [NumPy](http://www.numpy.org/) package can also be installed. 


#### Python script to extract names and download links of the Sentinel-1 Level-1C GRD scenes that were used to create the BigEarthNet-S1 v1.0 image patches ([extract_tile_names_and_links.py](https://git.tu-berlin.de/rsim/BigEarthNet-S1_tools/-/blob/master/scripts/extract_scene_names_and_links.py)) 

This script creates a csv file whose each row contains the patch name, corresponding Sentinel-1 GRD scene filename and tile download link. You can directly use the resulting file from [files/scene_names_and_links.csv](https://git.tu-berlin.de/rsim/BigEarthNet-S1_tools/-/blob/master/files/scene_names_and_links.csv) without running the script.

* Examples: 

```
python extract_tile_names_and_links.py -r BigEarthNet-S1-v1.0/ -u <COPERNICUS_HUB_USERNAME> -p <COPERNICUS_HUB_PASSWORD> -o tile_names_links.csv
```

* Requirements for running:

The BigEarthNet-S1 v1.0 archive should be downloaded first. [sentinelsat](https://github.com/sentinelsat/sentinelsat) package should be installed to search tiles within Copernicus Open Access Hub via sentinelsat API. 

# Author
Arne de Wall

# Maintained by
**[RSiM Team](https://www.rsim.tu-berlin.de/menue/team)**



# License
The BigEarthNet archive is licensed under the **Community Data License Agreement – Permissive, Version 1.0** ([Text](https://cdla.io/permissive-1-0/)).

The code in this repository to facilitate the use of the archive is licensed under the **MIT License**:

```
MIT License

Copyright (c) 2020 The BigEarthNet Authors

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
```
